@@ -7,8 +7,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-spell-fu
 ;; Keywords: convenience
-;; Package-Version: 20251126.529
-;; Package-Revision: 437f594615c5
+;; Package-Version: 20260106.49
+;; Package-Revision: a2e009e664d5
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -16,7 +16,7 @@
 ;; This package checks the spelling of on-screen text.
 ;;
 
-;;; Usage
+;;; Usage:
 
 ;;
 ;; Write the following code to your .emacs file:
@@ -78,7 +78,7 @@
 
 (defcustom spell-fu-directory (locate-user-emacs-file "spell-fu" ".emacs-spell-fu")
   "The directory to store dictionary data."
-  :type 'string)
+  :type 'directory)
 
 (defcustom spell-fu-idle-delay 0.25
   "Idle time to wait before highlighting.
@@ -92,7 +92,7 @@ Set to 0.0 to highlight immediately (as part of syntax highlighting)."
 (defcustom spell-fu-word-delimit-camel-case nil
   "Support camel-case for delimiting word boundaries.
 
-So `HelloWorld' would be checked a two words instead of one.
+So `HelloWorld' would be checked as two words instead of one.
 This is performed as an additional check for words that would
 otherwise be marked as incorrect."
   :type 'boolean)
@@ -180,7 +180,7 @@ over which words are being checked.
 
 Notes:
 
-- The ranges passed in a guaranteed to be on line boundaries.
+- The ranges passed in are guaranteed to be on line boundaries.
 - Calling `spell-fu-check-word' on each word.
 
 - You may explicitly mark a range as incorrect using
@@ -198,10 +198,10 @@ Notes:
 ;; Always check this has not been deleted (has a valid buffer) before use.
 (defvar-local spell-fu--idle-overlay-last nil)
 
-;; Cache the result of: `(mapcar (lambda (dict) (symbol-value dict)) spell-fu-dictionaries)'
+;; Cache the result of: `(mapcar #'symbol-value spell-fu-dictionaries)'
 (defvar-local spell-fu--cache-table-list nil)
 
-;; The buffer local dictionary generated from `spell-fu-buffer-session-localwords'.
+;; The buffer-local dictionary generated from `spell-fu-buffer-session-localwords'.
 (defvar-local spell-fu--buffer-localwords-cache-table nil)
 
 ;; Map `spell-fu-buffer-session-localwords' identity to existing
@@ -231,7 +231,7 @@ Notes:
 ;; Dictionary Utility Functions
 
 (defsubst spell-fu--canonicalize-word-downcase (word)
-  "Return lowercase UTF-8 encoded WORD (must already be `downcase')."
+  "Return lowercase UTF-8 encoded WORD (must already be lowercase)."
   (encode-coding-string word 'utf-8))
 
 (defsubst spell-fu--canonicalize-word (word)
@@ -281,7 +281,7 @@ Notes:
                                (hash-table-size (symbol-value dict))))))
 
 (defun spell-fu--dictionaries-test-any (test-fn)
-  "Remove any dictionaries that match TEST-FN."
+  "Return non-nil if any dictionaries match TEST-FN."
   (declare (important-return-value t))
   (let ((result nil))
     (let ((dict-list spell-fu-dictionaries))
@@ -293,7 +293,7 @@ Notes:
     result))
 
 (defun spell-fu--dictionaries-remove-any (test-fn)
-  "Return non-nil if any dictionaries match TEST-FN."
+  "Remove any dictionaries that match TEST-FN."
   (declare (important-return-value nil))
   (setq spell-fu-dictionaries
         (remq
@@ -302,26 +302,25 @@ Notes:
           (lambda (dict)
             (cond
              ((funcall test-fn dict)
-              dict)
+              nil)
              (t
-              nil)))
+              dict)))
           spell-fu-dictionaries))))
 
 (defun spell-fu--cache-file (dict)
-  "Return the location of the cache file with dictionary DICT."
+  "Return the location of the cache file for dictionary DICT."
   (declare (important-return-value t))
   (expand-file-name (format "words_%s.el.data" (symbol-name dict)) spell-fu-directory))
 
 (defun spell-fu--words-file (dict)
-  "Return the location of the word-list with dictionary DICT."
+  "Return the location of the word-list for dictionary DICT."
   (declare (important-return-value t))
   (expand-file-name (format "words_%s.txt" (symbol-name dict)) spell-fu-directory))
 
 (defun spell-fu--refresh-cache-table-list ()
   "Refresh internal list `spell-fu--cache-table-list'."
   (declare (important-return-value nil))
-  (setq spell-fu--cache-table-list
-        (mapcar (lambda (dict) (symbol-value dict)) spell-fu-dictionaries)))
+  (setq spell-fu--cache-table-list (mapcar #'symbol-value spell-fu-dictionaries)))
 
 (defun spell-fu--refresh ()
   "Reset spell-checked overlays in the current buffer."
@@ -343,7 +342,7 @@ Notes:
         (spell-fu--refresh)))))
 
 (defun spell-fu--get-edit-candidate-dictionaries (word action)
-  "Return dictionaries for which it make sense to perform ACTION on WORD.
+  "Return dictionaries for which it makes sense to perform ACTION on WORD.
 
 ACTION is `'remove' or `'add'.  Returned candidates are dictionaries
 which support the operation, and correspondingly do / do not
@@ -453,10 +452,9 @@ Optional argument BODY runs with the depth override."
      ,@body))
 
 (defmacro spell-fu--setq-expand-range-to-line-boundaries (pos-beg pos-end)
-  "Set POS-BEG the the line beginning, POS-END to the line end."
-  ;; Ignore field boundaries.
-  (let ((inhibit-field-text-motion t))
-    `(save-excursion
+  "Set POS-BEG to the line beginning, POS-END to the line end."
+  `(let ((inhibit-field-text-motion t))
+     (save-excursion
        ;; Extend the ranges to line start/end.
        (goto-char ,pos-end)
        (setq ,pos-end (pos-eol))
@@ -570,11 +568,11 @@ save some time by not spending time reading it back."
       (setq word-table (make-hash-table :test #'equal :size (count-lines (point-min) (point-max))))
       (while (null (eobp))
         (let ((l (buffer-substring-no-properties (pos-bol) (pos-eol))))
-          ;; Value of 't' is just for simplicity, it's no used except for check the item exists.
+          ;; Value of 't' is just for simplicity, it's not used except to check the item exists.
           (puthash (spell-fu--canonicalize-word l) t word-table)
           (forward-line 1))))
 
-    ;; Write write it to a file.
+    ;; Write it to a file.
     (with-temp-buffer
       (prin1 cache-header (current-buffer))
       (prin1 word-table (current-buffer))
@@ -591,9 +589,8 @@ save some time by not spending time reading it back."
         (spell-fu--cache-from-word-list-impl words-file cache-file)
       (error
        ;; Should be rare: if the file is corrupt or cannot be read for any reason.
-       (progn
-         (message "failed, %s" (error-message-string err))
-         nil)))))
+       (message "failed, %s" (error-message-string err))
+       nil))))
 
 (defun spell-fu--cache-words-load-impl (cache-file)
   "Return the Lisp content from reading CACHE-FILE.
@@ -628,9 +625,8 @@ the caller will need to regenerate the cache."
         (spell-fu--cache-words-load-impl cache-file)
       (error
        ;; Should be rare: if the file is corrupt or cannot be read for any reason.
-       (progn
-         (message "failed, %s" (error-message-string err))
-         nil)))))
+       (message "failed, %s" (error-message-string err))
+       nil))))
 
 
 ;; ---------------------------------------------------------------------------
@@ -714,9 +710,9 @@ Otherwise remove all overlays."
   (let ((item-ov (make-overlay pos-beg pos-end)))
     (overlay-put item-ov 'spell-fu-mode t)
     (overlay-put item-ov 'face 'spell-fu-incorrect-face)
-    (overlay-put item-ov 'modification-hooks 'spell-fu--removed-changed-overlay)
-    (overlay-put item-ov 'insert-in-front-hooks 'spell-fu--removed-changed-overlay)
-    (overlay-put item-ov 'insert-behind-hooks 'spell-fu--removed-changed-overlay)
+    (overlay-put item-ov 'modification-hooks '(spell-fu--removed-changed-overlay))
+    (overlay-put item-ov 'insert-in-front-hooks '(spell-fu--removed-changed-overlay))
+    (overlay-put item-ov 'insert-behind-hooks '(spell-fu--removed-changed-overlay))
     (overlay-put item-ov 'evaporate t)
     item-ov))
 
@@ -791,10 +787,10 @@ Argument POS-END the end position of WORD."
 ;; ---------------------------------------------------------------------------
 ;; Range Checking Commands
 ;;
-;; These functions are value values for the `spell-fu-check-range' buffer local variable.
+;; These functions are valid values for the `spell-fu-check-range' buffer-local variable.
 ;;
-;; Note that the callers of these function extends the range to line delimiters,
-;; to ensure there no chance of the points being in the middle of a word.
+;; Note that the callers of these functions extend the range to line delimiters,
+;; to ensure there is no chance of the points being in the middle of a word.
 ;;
 
 (defun spell-fu--check-faces-at-point (pos)
@@ -956,12 +952,11 @@ when checking the entire buffer for example."
                         (funcall spell-fu-check-range pos-beg pos-end)
                         t)
                     (error
-                     (progn
-                       ;; Keep since this should be very rare.
-                       (message "Early exit 'spell-fu-mode': %s" (error-message-string err))
-                       ;; Break out of the loop.
-                       (setq overlays-in-view nil)
-                       nil)))
+                     ;; Keep since this should be very rare.
+                     (message "Early exit 'spell-fu-mode': %s" (error-message-string err))
+                     ;; Break out of the loop.
+                     (setq overlays-in-view nil)
+                     nil))
 
               ;; Don't delete the overlay since it may extend outside the window bounds,
               ;; always delete the range instead.
@@ -1000,7 +995,7 @@ when checking the entire buffer for example."
       ;; Handy for debugging pending regions to be checked.
       ;; (overlay-put item-ov 'face '(:background "#000000" :extend t))
       (overlay-put item-ov 'spell-fu-pending t)
-      (overlay-put item-ov 'evaporate 't)
+      (overlay-put item-ov 'evaporate t)
       (setq spell-fu--idle-overlay-last item-ov)))
 
   ;; Use `inhibit-quit' as a way to check if `jit-lock-stealth' is in use.
@@ -1014,15 +1009,15 @@ when checking the entire buffer for example."
 ;; This works as follows:
 ;;
 ;; - The timer is kept active as long as the local mode is enabled.
-;; - Entering a buffer runs the buffer local `window-state-change-hook'
+;; - Entering a buffer runs the buffer-local `window-state-change-hook'
 ;;   immediately which checks if the mode is enabled,
 ;;   set up the global timer if it is.
-;; - Switching any other buffer wont run this hook,
-;;   rely on the idle timer it's self running, which detects the active mode,
-;;   canceling it's self if the mode isn't active.
+;; - Switching to any other buffer won't run this hook;
+;;   we rely on the idle timer itself running, which detects the active mode,
+;;   canceling itself if the mode isn't active.
 ;;
 ;; This is a reliable way of using a global,
-;; repeating idle timer that is effectively buffer local.
+;; repeating idle timer that is effectively buffer-local.
 ;;
 
 ;; Global idle timer (repeating), keep active while the buffer-local mode is enabled.
@@ -1033,7 +1028,7 @@ when checking the entire buffer for example."
 (defvar-local spell-fu--dirty nil)
 
 (defun spell-fu--time-callback-or-disable ()
-  "Callback that run the repeat timer."
+  "Callback that runs the repeat timer."
   (declare (important-return-value nil))
 
   ;; Ensure all other buffers are highlighted on request.
@@ -1100,7 +1095,7 @@ when checking the entire buffer for example."
     (spell-fu--time-ensure nil))))
 
 (defun spell-fu--time-buffer-local-enable ()
-  "Ensure buffer local state is enabled."
+  "Ensure buffer-local state is enabled."
   (declare (important-return-value nil))
   ;; Needed in case focus changes before the idle timer runs.
   (setq spell-fu--dirty-flush-all t)
@@ -1109,7 +1104,7 @@ when checking the entire buffer for example."
   (add-hook 'window-state-change-hook #'spell-fu--time-reset nil t))
 
 (defun spell-fu--time-buffer-local-disable ()
-  "Ensure buffer local state is disabled."
+  "Ensure buffer-local state is disabled."
   (declare (important-return-value nil))
   (kill-local-variable 'spell-fu--dirty)
   (spell-fu--time-ensure nil)
@@ -1247,47 +1242,53 @@ Return t when found, otherwise nil."
   (interactive)
   (spell-fu--goto-next-or-previous-error -1))
 
-(defun spell-fu-word-add (dict)
+(defun spell-fu-word-add (dict &optional word)
   "Add the current word to the dictionary DICT.
 
-Return t when the word has been added."
+Return t when the word has been added.
+WORD defaults to the word at point if not provided."
   (declare (important-return-value nil))
-  (interactive (list
-                (spell-fu--read-dictionary
-                 (spell-fu--get-edit-candidate-dictionaries
-                  (spell-fu--word-at-point) 'add)
-                 "Add to dictionary: ")))
-  (let ((word (spell-fu--word-at-point)))
-    (cond
-     (dict
-      (let ((encoded-word (spell-fu--canonicalize-word word)))
-        (funcall (get dict 'add-word) encoded-word)
-        (puthash encoded-word t (symbol-value dict))
-        t))
-     (t
-      (message "Cannot add %S to any active dictionary." word)
-      nil))))
+  (interactive (let ((w (spell-fu--word-at-point)))
+                 (list
+                  (spell-fu--read-dictionary
+                   (spell-fu--get-edit-candidate-dictionaries w 'add) "Add to dictionary: ")
+                  w)))
+  (unless word
+    (setq word (spell-fu--word-at-point)))
+  (cond
+   (dict
+    (let ((encoded-word (spell-fu--canonicalize-word word)))
+      (funcall (get dict 'add-word) encoded-word)
+      (puthash encoded-word t (symbol-value dict))
+      t))
+   (t
+    (message "Cannot add %S to any active dictionary." word)
+    nil)))
 
-(defun spell-fu-word-remove (dict)
+(defun spell-fu-word-remove (dict &optional word)
   "Remove the current word from the dictionary DICT.
 
-Return t when the word has been removed."
+Return t when the word has been removed.
+WORD defaults to the word at point if not provided."
   (declare (important-return-value nil))
-  (interactive (list
-                (spell-fu--read-dictionary
-                 (spell-fu--get-edit-candidate-dictionaries
-                  (spell-fu--word-at-point) 'remove)
-                 "Remove from dictionary: ")))
-  (let ((word (spell-fu--word-at-point)))
-    (cond
-     (dict
-      (let ((encoded-word (spell-fu--canonicalize-word word)))
-        (funcall (get dict 'remove-word) encoded-word)
-        (remhash encoded-word (symbol-value dict))
-        t))
-     (t
-      (message "Cannot remove %S from any active dictionary." word)
-      nil))))
+  (interactive (let ((w (spell-fu--word-at-point)))
+                 (list
+                  (spell-fu--read-dictionary
+                   (spell-fu--get-edit-candidate-dictionaries
+                    w 'remove)
+                   "Remove from dictionary: ")
+                  w)))
+  (unless word
+    (setq word (spell-fu--word-at-point)))
+  (cond
+   (dict
+    (let ((encoded-word (spell-fu--canonicalize-word word)))
+      (funcall (get dict 'remove-word) encoded-word)
+      (remhash encoded-word (symbol-value dict))
+      t))
+   (t
+    (message "Cannot remove %S from any active dictionary." word)
+    nil)))
 
 (defun spell-fu-dictionary-add (dict)
   "Add DICT to the list of active dictionaries."
@@ -1307,7 +1308,7 @@ Return t when the word has been removed."
     (spell-fu--refresh)))
 
 (defun spell-fu-reset ()
-  "Reset spell-fu and it's cache, useful if the cache has somehow become invalid."
+  "Reset spell-fu and its cache, useful if the cache has somehow become invalid."
   (declare (important-return-value nil))
   (interactive)
   (let ((buffers-in-mode nil))
@@ -1333,7 +1334,7 @@ Return t when the word has been removed."
               (buffers-in-mode
                "")
               (t
-               " no buffers in spell-fu found, generate cache on next use!")))))
+               "; no spell-fu buffers found, generate cache on next use!")))))
 
 ;; ---------------------------------------------------------------------------
 ;; Ispell / Aspell dictionary support
@@ -1355,7 +1356,7 @@ Return t if the file was updated."
                dict-file
                (spell-fu--file-is-older
                 words-file
-                ;; Chase links is needed as checking the symbolic-link date isn't correct, #31.
+                ;; Chasing links is needed as checking the symbolic-link date isn't correct, #31.
                 (file-chase-links dict-file))))
          ;; Return value, failure to run `aspell' leaves this nil.
          (updated nil))
@@ -1421,8 +1422,8 @@ Return t if the file was updated."
 
                 (setq word-list (spell-fu--buffer-as-line-list (current-buffer) word-list)))))
 
-          ;; Case insensitive sort is important if this is used for `ispell-complete-word-dict'.
-          ;; Which is a handy double-use for this file.
+          ;; Case insensitive sort is important if this is used for `ispell-complete-word-dict',
+          ;; which is a handy double-use for this file.
           (when updated
             (let ((word-list-ncase nil))
               (dolist (word word-list)
@@ -1542,7 +1543,7 @@ Return t if the file was updated."
          (is-dict-outdated
           (and has-words-file
                has-dict-personal
-               ;; Chase links is needed as checking the symbolic-link date isn't correct, #31.
+               ;; Chasing links is needed as checking the symbolic-link date isn't correct, #31.
                (spell-fu--file-is-older words-file (file-chase-links personal-words-file)))))
 
     (when (or (null has-words-file) is-dict-outdated)
@@ -1561,13 +1562,13 @@ Return t if the file was updated."
               (when (looking-at-p "personal_ws-")
                 (delete-region (pos-bol) (1+ (pos-eol))))
               (goto-char (point-max))
-              (unless (eq ?\n (char-after))
+              (unless (eq ?\n (char-before))
                 (insert "\n")))
 
             (setq word-list (spell-fu--buffer-as-line-list (current-buffer) word-list)))
 
-          ;; Case insensitive sort is important if this is used for `ispell-complete-word-dict'.
-          ;; Which is a handy double-use for this file.
+          ;; Case insensitive sort is important if this is used for `ispell-complete-word-dict',
+          ;; which is a handy double-use for this file.
           (let ((word-list-ncase nil))
             (dolist (word word-list)
               (push (cons (downcase word) word) word-list-ncase))
@@ -1620,7 +1621,7 @@ Argument DICT-FILE is the absolute path to the dictionary."
         (insert-file-contents-literally dict-file)
 
         ;; Ensure newline at EOF,
-        ;; not essential but complicates sorted add if we don't do this.
+        ;; not essential but complicates sorted adding if we don't do this.
         ;; also ensures we can step past the header which _could_ be a single line
         ;; without anything below it.
         (goto-char (point-max))
@@ -1756,7 +1757,7 @@ Argument DICT-FILE is the absolute path to the dictionary."
     (setq spell-fu--buffer-localwords-cache-table word-table)))
 
 (defun spell-fu--buffer-localwords-add-or-remove (word action)
-  "Add or remove WORD from buffer local names depending on ACTION."
+  "Add or remove WORD from buffer-local words depending on ACTION."
   (declare (important-return-value t))
   (catch 'result
     (spell-fu--with-message-prefix "Spell-fu: "
@@ -1781,7 +1782,7 @@ Argument DICT-FILE is the absolute path to the dictionary."
 
            ((eq action 'remove)
             (unless word-in-dict
-              (message "\"%s\" not in the personal dictionary." word)
+              (message "\"%s\" not in the local dictionary." word)
               (throw 'result nil))
 
             (setq spell-fu-buffer-session-localwords
@@ -1806,7 +1807,7 @@ Argument DICT-FILE is the absolute path to the dictionary."
     ;; Start with no words - construct them lazily
     (set dict nil)
     ;; Set description
-    (put dict 'description "Buffer local dictionary")
+    (put dict 'description "Buffer-local dictionary")
     ;; Set update function
     (put dict 'update #'spell-fu--buffer-localwords-cache-table-update)
     ;; Set add/remove functions
